==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/Api/Flowcontrol/V1beta3/NonResourcePolicyRule.pm <==
package IO::K8s::Api::Flowcontrol::V1beta3::NonResourcePolicyRule;
# ABSTRACT: NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s nonResourceURLs => [Str], 'required';


k8s verbs => [Str], 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Flowcontrol::V1beta3::NonResourcePolicyRule - NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.

=head1 VERSION

version 1.000

=head2 nonResourceURLs

C<nonResourceURLs> is a set of url prefixes that a user should have access to and may not be empty. For example:

=over 4

=item * "/healthz" is legal

=item * "/hea*" is illegal

=item * "/hea" is legal but matches nothing

=item * "/hea/*" also matches nothing

=item * "/healthz/*" matches all per-component health checks.

=back

"*" matches all non-resource urls. if it is present, it must be the only entry. Required.

=head2 verbs

C<verbs> is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/Api/Flowcontrol/V1beta3/NonResourcePolicyRule.pm <==
package IO::K8s::Api::Flowcontrol::V1beta3::NonResourcePolicyRule;
# ABSTRACT: NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s nonResourceURLs => [Str], 'required';


k8s verbs => [Str], 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Flowcontrol::V1beta3::NonResourcePolicyRule - NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.

=head1 VERSION

version 1.001

=head2 nonResourceURLs

C<nonResourceURLs> is a set of url prefixes that a user should have access to and may not be empty. For example:

=over 4

=item * "/healthz" is legal

=item * "/hea*" is illegal

=item * "/hea" is legal but matches nothing

=item * "/hea/*" also matches nothing

=item * "/healthz/*" matches all per-component health checks.

=back

"*" matches all non-resource urls. if it is present, it must be the only entry. Required.

=head2 verbs

C<verbs> is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
